"""LimitlessLED Version 4 Module

From what I can gather on http://www.limitlessled.com/dev
this should also be compatible with a version 5 wifi bridge.
"""
import socket
import math
import logging
import time
from mookfist_lled_controller.exceptions import NoBridgeFound
from mookfist_lled_controller.exceptions import InvalidGroup

def get_bridges():
    """Get available bridges"""

    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    sock.settimeout(2)
    sock.bind(('', 0))
    sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
    sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)

    counter = 0
    max_tries = 5

    bridges = []

    while counter < max_tries:
        try:
            sock.sendto(bytearray('Link_Wi-Fi'.encode('utf8')), ('255.255.255.255', 48899))
            data = sock.recv(1024)
            if data:
                host, mac = data.split(','.encode('utf8'))[:2]
                
                bridge = (host.decode('utf8'),mac.decode('utf8'))
                if bridge not in bridges:
                    bridges.append(bridge)
            time.sleep(1)
            counter = counter + 1
        except socket.timeout:
            counter = counter + 1

    
    return tuple(bridges)

class Bridge(object):
    def __init__(self, ip, port, pause=100, repeat=1, *args, **kwargs):
        self.ip = ip
        self.port = port
        self.pause = pause / 1000.0
        self.repeat = repeat
        self._groups = {}

        self._Group = kwargs.get('group_class', Group)

        self._sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        self._last_set_group = -1

        self.logger = logging.getLogger('bridge')


    def get_group(self, group):
        self.logger.warn('Group: %s' % group)
        self.logger.warn('Groups: %s' % self._groups)
        if group not in self._groups:
            self._groups[group] = self._Group(group)
        return self._groups[group]

    def color(self, color, group=1):
        g = self.get_group(group)
        if self._last_set_group != group:
            self.send(g.on())
            self._last_set_group = group

        self.send(g.color(color))

    def off(self, group=1):
        g = self.get_group(group)
        self.send(g.off())

    def on(self, group=1):
        g = self.get_group(group)
        self.send(g.on())

    def white(self, group=1):
        g = self.get_group(group)

        if group == 1:
            self.send(Command(0x45))
            self.send(Command(0xC5))
        elif group == 2:
            self.send(Command(0x47))
            self.send(Command(0xC7))
        elif group == 3:
            self.send(Command(0x49))
            self.send(Command(0xC9))
        elif group == 4:
            self.send(Command(0x4b))
            self.send(Command(0xcb))


    def brightness(self, brightness, group=1):
        g = self.get_group(group)

        if self._last_set_group != group:
            self.send(g.on())
            self._last_set_group = group

        self.send(g.brightness(brightness))

    def send(self, cmd):
        for x in range(0, self.repeat):
            self.logger.debug('Sending command: %s' % cmd.message())
            self._sock.sendto(bytearray(cmd.message()), (self.ip, self.port))
            time.sleep(self.pause)



class Command(object):
    """A LimitlessLED Command"""

    def __init__(self, cmd, value=0x00, suffix=None):
        """
        cmd: command to send
        value: value of command, if any (defaults to 0x00)
        suffix: suffix value at the end of the command if any
        """
        self.cmd = cmd
        self.value = value
        self.suffix = suffix

    def message(self):
        """Get an array representation of the message"""
        if self.suffix != None:
            return [self.cmd, self.value, self.suffix]
        else:
            return [self.cmd, self.value]


class Group(object):
    """Represents a group of lights"""

    def __init__(self, group):
        """
        group: group number (1-4)
        """
        self.group = group

    def on(self):
        """
        get the On command for this group
        """
        if self.group == 1:
            cmd = 0x45
        elif self.group == 2:
            cmd = 0x47
        elif self.group == 3:
            cmd = 0x49
        elif self.group == 4:
            cmd = 0x4B
        else:
            raise InvalidGroup() 

        return Command(cmd)

    def off(self):
        """
        get the Off command for this group
        """
        if self.group == 1:
            cmd = 0x46
        elif self.group == 2:
            cmd = 0x48
        elif self.group == 3:
            cmd = 0x4A
        elif self.group == 4:
            cmd = 0x4C
        else:
            raise InvalidGroup()

        return Command(cmd)

    def color(self, color):
        """get the Color command for this group and color (0-255)"""
        color = color + 176
        if color > 255:
            color = color - 255
        return Command(0x40, color)

    def white(self):
        if self.group == 1:
            cmd = 0x45
        elif self.group == 2:
            cmd = 0x46
        elif self.group == 3:
            cmd = 0x47
        elif self.group == 4:
            cmd = 0x48

        return Command(cmd)

    def brightness(self, brightness):
        """"get the brightness command for this group and brightness (0-100%)
        
            LimitlessLED only supports values 2 to 27 for brightness, so this percentage
            is actually a percentage of the value 25
        
        """
        target_brightness = int(math.ceil(25 * (brightness / 100.0)) + 2)

        """get the Brightness command for this group and brightnes (2-27)"""
        return Command(0x4E, target_brightness)




"""Bridge Abstraction Layer

Provides a consistent way of talking to different Limitless LED
protocols
"""
import socket
import time
import logging

def get_bridges(version=4):
    """Get Bridge

    Returns a list of IP and MAC addresses on the network
    """

    if version == 4 or version == 5:
        from mookfist_lled_controller.bridges.ver4 import get_bridges as gb
    elif version == 6:
        from mookfist_lled_controller.bridges.ver6 import get_bridges as gb
    else:
        raise Exception("Unsupported protocol version: %s" % version)

    return gb()


class WifiBridge(object):
    """Wifi Bridge Class

    Abstraction against different LimitlessLED bridge versions
    """
    def __init__(self, ip, port, version=4, pause=100, repeat=1):
        """
        ip: IP Address of the wifi bridge
        port: Port number of the wifi bridge
        version: Which LimitlessLED wifi version to use
        pause: Delay in milliseconds between commands
        repeat: Number of times to repeat the same command
        """
        self.ip = ip
        self.port = port
        self.pause = pause / 1000.0
        self.repeat = repeat
        self._groups = {}

        if version == 4 or version == 5:
            from mookfist_lled_controller.bridges.ver4 import Bridge
        elif version == 6:
            from mookfist_lled_controller.bridges.ver6 import Bridge
        else:
            raise Exception("Unsupported protocol version: %s" % version)

        self._bridge = Bridge(ip, port, pause, repeat)

    def color(self, color, group=1):
        """
        Set the color for a group.

        Color ranges from 0 to 255, where 0 is red.
        """
        self._bridge.color(color, group)

    def brightness(self, brightness, group=1):
        """
        Set the brightness for a specific group

        Brightness ranges from 2 to 27
        """
        self._bridge.brightness(brightness, group)

    def white(self, group=1):
        self._bridge.white(group)

    def on(self, group=1):
        self._bridge.on(group)

    def off(self, group=1):
        self._bridge.off(group)



from .bridge import WifiBridge

from .bridge import get_bridges
from .actions import fade_brightness
from .actions import fade_color
from .actions import set_color
from .actions import set_brightness
from .actions import set_on
from .actions import set_off
from .actions import set_white

def pprint_bytearray(h):
    s = []
    for i in h:
        s.append(hex(i).replace('0x',''))
    return ' '.join(s)
    



"""Stuff for the CLI"""
import sys
import logging
from docopt import docopt
from mookfist_lled_controller import logger
from mookfist_lled_controller import WifiBridge
from mookfist_lled_controller import get_bridges
from mookfist_lled_controller import fade_brightness
from mookfist_lled_controller import fade_color
from mookfist_lled_controller import set_color
from mookfist_lled_controller import set_brightness
from mookfist_lled_controller import set_on
from mookfist_lled_controller import set_off
from mookfist_lled_controller import set_white
from mookfist_lled_controller.exceptions import UnsupportedVersion
from mookfist_lled_controller.exceptions import InvalidGroup
from mookfist_lled_controller.exceptions import NoBridgeFound
def configure_logger(debug=False):
    """Configure a logger with colored output"""

    formatter = logger.ColoredFormatter()
    handler   = logging.StreamHandler(sys.stdout)
    handler.setFormatter(formatter)

    log = logging.getLogger()

    if debug == True:
        log.setLevel(logging.DEBUG)
        handler.setLevel(logging.DEBUG)
    else:
        log.setLevel(logging.INFO)
        handler.setLevel(logging.INFO)

    log.addHandler(handler)

class Main(object):
    """the application"""

    def __init__(self, arguments):
        
        if arguments['fade']:
            self.action = 'fade'
        elif arguments['fadec']:
            self.action = 'fadec'
        elif arguments['color']:
            self.action = 'color'
        elif arguments['brightness']:
            self.action = 'brightness'
        elif arguments['on']:
            self.action = ['on']
        elif arguments['off']:
            self.action = 'off'
        elif arguments['white']:
            self.action = 'white'


        if arguments['--bridge-version'] == '4' or arguments['--bridge-version'] == '5':
            self.bridge_version = 4
        elif arguments['--bridge-version'] == '6':
            self.bridge_version = 6
        elif arguments['--bridge-version'] != None:
            raise UnsupportedVersion 
        else:
            self.bridge_version = 4

        self.log = logging.getLogger('lled')

        self.arguments = arguments

    def action_fade(self):
        start = int(self.arguments['<start>'])
        end   = int(self.arguments['<end>'])

        self.log.info('Fading lights from %s%% to %s%%' % (start, end))
        fade_brightness(self.bridge, self.arguments['--group'], start, end)

    def action_fadec(self):
        start = int(self.arguments['<start>'])
        end   = int(self.arguments['<end>'])

        self.log.info('Fading to color %s from %s' % (end, start))
        fade_color(self.bridge, self.arguments['--group'], start, end)

    def action_color(self):
        color = int(self.arguments['<color>'])

        self.log.info('Setting color to %s' % color)
        set_color(self.bridge, self.arguments['--group'], color)

    def action_white(self):
        self.log.info('Setting color to white')
        set_white(self.bridge, self.arguments['--group'])

    def action_brightness(self):
        brightness = int(self.arguments['<brightness>'])
        self.log.info('Setting brightness to %s%%' % brightness)
        set_brightness(self.bridge, self.arguments['--group'], brightness)

    def action_on(self):
        self.log.info('Turning lights on')
        set_on(self.bridge, self.arguments['--group'])

    def action_off(self):
        self.log.info('Turning lights off')
        set_off(self.bridge, self.arguments['--group'])

    def route_action(self):
        if self.arguments['fade']:
            self.action_fade()
        elif self.arguments['fadec']:
            self.action_fadec()
        elif self.arguments['color']:
            self.action_color()
        elif self.arguments['brightness']:
            self.action_brightness()
        elif self.arguments['on']:
            self.action_on()
        elif self.arguments['off']:
            self.action_off()
        elif self.arguments['white']:
            self.action_white()



    def run(self):
        try:
            if (self.arguments['--host']):
                host = self.arguments['--host']
            else:
                self.log.info('Scanning for bridge...')
                bridges = get_bridge(self.bridge_version)
                self.log.info('Found %s bridge(s)' % len(bridges))
                
                if len(bridges) > 1:
                    self.log.warning('Multiple bridges have been found. I will choose the first one I saw')
                    self.log.warning('If you really don\'t want me to do that, then use the --bridge-ip (and --bridge-port if needed) flags when using this tool')
                   
                    self.log.info('--- Available Bridges')
                    for bridge in bridges:
                        self.log.info('    %s - %s' % (bridge[0], bridge[1]))
                elif len(bridges) == 0:
                    raise NoBridgeFound
                
                host = bridges[0][0]

            
            rc = 1
            if self.arguments['--repeat']:
                rc = int(self.arguments['--repeat'])

            pause = 100
            if self.arguments['--pause']:
                pause = int(self.arguments['--pause'])

            version = 4
            if self.arguments['--bridge-version']:
                version = int(self.arguments['--bridge-version'])

            if version == 4 or version == 5:
                port = 8899
            elif version == 6:
                port = 5987
            elif self.arguments['--port']:
                port = int(self.arguments['--port'])

            self.log.info('--- Bridge Details')
            self.log.info('Version: %s' % version)
            self.log.info('IP: %s' % host)
            self.log.info('Port: %s' % port)
            self.log.debug('--- Settings')
            self.log.debug('Pause: %sms' % pause)
            self.log.debug('Command Repeat: %s' % rc)

            self.bridge = WifiBridge(host, port, version, pause, rc)
    
            self.route_action()
        except UnsupportedVersion:
            self.log.error('The chosen bridge version is unsupported')
        except InvalidGroup:
            self.log.error('Groups can be numbered 1 through 4 only')
        except NoBridgeFound:
            self.log.error('Sorry, I was not able to find any bridges. So either give me the IP (and port number) of the bridge you wish to use, or figure out why I can not find any bridges')





"""LimitlessLED Version 4 Module

From what I can gather on http://www.limitlessled.com/dev
this should also be compatible with a version 5 wifi bridge.
"""
import socket
import math
import logging
import time
from mookfist_lled_controller.exceptions import NoBridgeFound
from mookfist_lled_controller.exceptions import InvalidGroup
from mookfist_lled_controller import pprint_bytearray

def get_bridges():
    """Get available bridges"""

    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
    sock.settimeout(2)
    sock.bind(('', 0))
    sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
    sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)

    counter = 0
    max_tries = 5

    bridges = []

    while counter < max_tries:
        try:
            sock.sendto(bytearray('HF-A11ASSISTHREAD'.encode('utf8')), ('255.255.255.255', 48899))
            data = sock.recv(1024)
            if data:
                host, mac = data.split(','.encode('utf8'))[:2]
                bridge = (host.decode('utf8'), mac.decode('utf8'))
                if bridge not in bridges:
                    bridges.append(bridge)
            time.sleep(1)
            counter = counter + 1
        except socket.timeout:
            counter = counter + 1

    return tuple(bridges)


def format_hex(i):
    if i < 16:
        i = hex(i).replace('0x','0x0')
    else:
        i = hex(i)
    return i
    


class Command(object):
    """A LimitlessLED Command"""

    def __init__(self):
        """
        cmd: command to send
        value: value of command, if any (defaults to 0x00)
        suffix: suffix value at the end of the command if any
        """

        self._cmd = []

        for x in range(0,22):
            self._cmd.append(None)

        self._set_preamble()

    def _set_preamble(self):
        self[0] = 0x80
        self[1] = 0x00
        self[2] = 0x00
        self[3] = 0x00
        self[4] = 0x11
        self[7] = 0x00
        self[8] = 0x02
        self[9] = 0x00
        
    
    def __getitem__(self, key):
        key = int(key)
        if key >= len(self._cmd):
            raise "Invalid byte"
        else:
            return self._cmd[key]

    def __setitem__(self, key, value):
        key = int(key)
        if key >= len(self._cmd):
            raise "Invalid byte"
        else:
            self._cmd[key] = value

    def checksum(self, group):
        return sum(bytearray(self._cmd[10:21])) & 0xff

    def message(self):
        """Get an array representation of the message"""
        return self._cmd

    def message_str(self):
        return pprint_bytearray(self._cmd)


class Bridge(object):
    def __init__(self, ip, port=5987, pause=100, repeat=3, *args, **kwargs):
        self.ip = ip
        self.port = port
        self.pause = pause / 1000.0
        self.repeat = repeat
        self._groups = {}

        self._Group = kwargs.get('group_class', Group)

        self._sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        self._sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        self._sock.settimeout(2)
        self._last_set_group = -1

        self.logger = logging.getLogger('bridge6')

        self._wb1 = None
        self._wb2 = None
        self._cmd_counter = 0x01

    def get_session_ids(self):
        self.logger.debug('Getting session IDs')
        b = [
            0x20,
            0x00,
            0x00,
            0x00,
            0x16,
            0x02,
            0x62,
            0x3a,
            0xd5,
            0xed,
            0xa3,
            0x01,
            0xae,
            0x08,
            0x2d,
            0x46,
            0x61,
            0x41,
            0xa7,
            0xf6,
            0xdc,
            0xaf,
            0xf3,
            0xf7,
            0x00,
            0x00,
            0x1e
        ]


        self.send_raw(bytearray(b))

        data = self._sock.recv(1024)

        
        if data:

            db = bytearray(data)
            self.logger.debug('Response: %s' % pprint_bytearray(db))

            self._wb1 = db[19]
            self._wb2 = db[20]

            self.logger.debug('Session WB1: %s - Session WB2: %s' % (format_hex(self._wb1), format_hex(self._wb2)))

            self.confirm_init()


    def confirm_init(self):
        b = [
            0x80,
            0x00,
            0x00,
            0x00,
            0x11,
            self._wb1,
            self._wb2,
            0x00,
            self._cmd_counter,
            0x00,
            0x33,
            0x00,
            0x00,
            0x00,
            
            0x00,
            0x00,
            0x00,

            0x00,
            0x00,
            0x00,

            0x00,
            0x00,
            0x33
        ]

        self.logger.debug('Confirming initialization')
        self.send_raw(bytearray(b))

        data = self._sock.recv(1024)
        self.logger.debug('Response: %s' % pprint_bytearray(bytearray(data)))


    def get_group(self, group):
        if group not in self._groups:
            self._groups[group] = self._Group(group)
        return self._groups[group]

    def color(self, color, group=1):
        g = self.get_group(group)
        self.send(g.color(color))

    def brightness(self, brightness, group=1):
        g = self.get_group(group)
        self.send(g.brightness(brightness))

    def white(self, group=1):
        g = self.get_group(group)
        self.send(g.white())

    def on(self, group=1):
        g = self.get_group(group)
        self.send(g.on(),group)

    def off(self, group=1):
        g = self.get_group(group)
        self.send(g.off(),group)

    def send_raw(self, frame):
        self.logger.debug('Sending frame: %s' % pprint_bytearray(frame))
        self._sock.sendto(frame, (self.ip, self.port))
        self._cmd_counter = (self._cmd_counter + 1) % 255
        time.sleep(self.pause)

    def send(self, cmd, group=1):

        if self._wb1 == None or self._wb2 == None:
            self.get_session_ids()

        for x in range(0, self.repeat):
            cmd[5] = self._wb1
            cmd[6] = self._wb2
            cmd[7] = 0x00
            cmd[8] = self._cmd_counter
            cmd[9] = 0x00
            cmd[21] = cmd.checksum(group)

            self.send_raw(bytearray(cmd.message()))
            
            response = self._sock.recv(1024)
            self.logger.debug('Response: %s' % pprint_bytearray(bytearray(response)))




class Group(object):
    """Represents a group of lights"""

    def __init__(self, group, bulbtype=0x07):
        """
        group: group number (1-4)
        """
        self.group = group
        self.bulbtype = bulbtype

        self._command_counter = 0

    def _prepare_cmd(self):
        cmd = Command()
        cmd[10] = 0x31
        cmd[11] = 0x00
        cmd[12] = 0x00
        cmd[13] = self.bulbtype
        cmd[16] = 0x00
        cmd[17] = 0x00
        cmd[18] = 0x00
        cmd[19] = self.group
        cmd[20] = 0x00
        return cmd


    def on(self):
        """
        get the On command for this group
        """

        cmd = self._prepare_cmd()
        cmd[14] = 0x03
        cmd[15] = 0x01
        return cmd

    def off(self):
        """
        get the Off command for this group
        """
        cmd = self._prepare_cmd()
        cmd[14] = 0x03
        cmd[15] = 0x02
        return cmd

    def color(self, color):
        """get the Color command for this group and color (0-255)"""
        cmd = self._prepare_cmd()
        cmd[14] = 0x01
        cmd[15] = color
        cmd[16] = color
        cmd[17] = color
        cmd[18] = color
        color = color + 176
        if color > 255:
            color = color - 255
        return cmd
        # return Command(0x40, color)

    def white(self):
        cmd = self._prepare_cmd()
        cmd[14] = 0x03
        cmd[15] = 0x05
        return cmd

    def brightness(self, brightness):
        """"get the brightness command for this group and brightness (0-100%)
        
            LimitlessLED only supports values 2 to 27 for brightness, so this percentage
            is actually a percentage of the value 25
        
        """
        target_brightness = int(math.ceil(25 * (brightness / 100.0)) + 2)
        cmd = self._prepare_cmd()
        cmd[14] = 0x02
        cmd[15] = brightness

        return cmd

        """get the Brightness command for this group and brightnes (2-27)"""
        # return Command(0x4E, target_brightness)




import logging
from colorama import Fore

LVL_NAMES = {
    'DEBUG': Fore.CYAN,
    'INFO': Fore.GREEN,
    'WARNING': Fore.YELLOW,
    'ERROR': Fore.RED,
    'CRTICIAL': Fore.MAGENTA
}

class ColoredFormatter(logging.Formatter):

    def format(self, record):
        lvlname_color = LVL_NAMES[record.levelname]

        lvlname = record.levelname.ljust(8)

        lvl = '%s[%s%s%s]' % (Fore.WHITE, lvlname_color, lvlname, Fore.WHITE)
        msg = lvl + ' ' + Fore.RESET + record.msg
        return msg

def get_logger(name, level=logging.INFO):

    handler = logging.StreamHandler()
    handler.setFormatter(ColoredFormatter())

    logger = logging.getLogger(name)
    logger.setLevel(level)
    logger.addHandler(handler)

    return logger
    



"""Action Functions

Helper functions that perform different actions on a bridge
"""

def set_off(bridge, groups):
    """Turn off lights"""
    for grp in groups:
        bridge.off(int(grp))

def set_on(bridge, groups):
    """Turn on lights"""
    for grp in groups:
        bridge.on(int(grp))

def set_white(bridge, groups):
    for grp in groups:
        bridge.white(int(grp))

def fade_brightness(bridge, groups, start, end):
    """Fade the brightness of the selected groups"""

    if start > end:
        cmds = list(reversed(range(end, start)))
    else:
        cmds = range(start, end)


    for cmd in cmds:
        for grp in groups:
            bridge.brightness(cmd, int(grp))


def fade_color(bridge, groups, start, end):
    """Fade the color of the selected groups"""
    if start > end:
        cmds = list(reversed(range(end, start)))
    else:
        cmds = range(start, end)

    for cmd in cmds:
        for grp in groups:
            bridge.color(cmd, int(grp))


def set_color(bridge, groups, color):
    """Set the color of the selected groups"""
    for grp in groups:

        bridge.color(color, int(grp))


def set_brightness(bridge, groups, brightness):
    """Set the brightness of the selected groups"""
    for grp in groups:
        bridge.brightness(brightness, int(grp))



#!/usr/bin/env python
"""Mookfist LimitlessLED Control

This tool can be used to control your LimitlessLED based lights.

Usage:
    lled.py fade <start> <end> (--group=<GROUP>)... [options]
    lled.py fadec <start> <end> (--group=<GROUP>)... [options]
    lled.py fadeb <startb> <endb> <startc> <endc> (--group=<GROUP>)... [options]
    lled.py on (--group=<group>)... [options]
    lled.py off (--group=<group>)... [options]
    lled.py color <color> (--group=<GROUP>)... [options]
    lled.py white (--group=<GROUP>)... [options]
    lled.py brightness <brightness> (--group=<GROUP>)... [options]

Options:
    -h --host=HOST            IP / Hostname of the bridge
    -p --port=PORT            Port number of the bridge (defaults to 8899)
    -g GROUP --group=GROUP    Group number
    -r RC --repeat=RC         Number of times to repeat a command
    --pause=PAUSE             Number of milliseconds to wait between commands
    --bridge-version=VERSION  Specify the bridge version (defaults to 4)
    --debug                   Enable debugging output
    -h --help                 Show this help
"""
import sys
import logging
from docopt import docopt

from mookfist_lled_controller.cli import configure_logger
from mookfist_lled_controller.cli import Main

def main():
    arguments = docopt(__doc__, version='Mookfist LimitlessLED Control 0.0.1')
    configure_logger(arguments['--debug'])

    log = logging.getLogger('lled')

    log.info('Welcome to the Mookfist LimitlessLED Controller')

    try:
        m = Main(arguments)
        m.run()
    except KeyboardInterrupt:
        log.warning('Stopping')


if __name__ == '__main__':
    main()



import os
from setuptools import setup

__doc__ = """A python library for communicating with LimitlessLED/Milight/Easybulb compatible wifi bridges."""

setup(
    name="mookfist-lled-controller",
    description=__doc__,
    version="0.0.11",
    author="mookfist",
    author_email="mookfist@gmail.com",
    url="https://github.com/mookfist/mookfist-lled-controller",
    scripts=['lled.py'],
    packages=['mookfist_lled_controller','mookfist_lled_controller.bridges'],
    install_requires=[
        'docopt',
        'colorama'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Utilities',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3'
    ],
    keywords=['milight','limitlessled']
)



"""Exceptions"""

class NoBridgeFound(Exception):
    """Thrown when no bridge can found"""
    pass


class UnsupportedVersion(Exception):
    """Throw when an unsuppoted version is used"""
    pass


class InvalidGroup(Exception):
    """Thrown when using an invalid group"""
    pass
